@@ -1,13 +1,6 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
-
 from rest_framework import fields, serializers
 
-from haupt.db.abstracts.getter import get_lineage_model
+from haupt.db.defs import Models
 
 
 class RunArtifactLightSerializer(serializers.ModelSerializer):
@@ -15,7 +8,7 @@ class RunArtifactLightSerializer(serializers.ModelSerializer):
     kind = fields.SerializerMethodField()
 
     class Meta:
-        model = get_lineage_model()
+        model = Models.ArtifactLineage
         fields = ("name", "kind", "is_input")
 
     def get_name(self, obj):
@@ -79,7 +72,7 @@ class RunArtifactNameSerializer(serializers.ModelSerializer):
     name = fields.SerializerMethodField()
 
     class Meta:
-        model = get_lineage_model()
+        model = Models.ArtifactLineage
         fields = ("name",)
 
     def get_name(self, obj):
