@@ -1,10 +1,3 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
-
 from django.apps import AppConfig
 
 
@@ -14,6 +7,8 @@ class SchedulerConfig(AppConfig):
 
     def ready(self):
         import haupt.db.signals.runs  # noqa
+        import haupt.db.signals.stats  # noqa
+        import haupt.db.signals.stats  # noqa
         from haupt.common import auditor, conf
         from haupt.orchestration import executor, operations
 
