@@ -1,10 +1,3 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
-
 import click
 
 
@@ -34,6 +27,7 @@ import click
     help="UNIX domain socket binding.",
 )
 def streams(host: str, port: int, workers: int, per_core: bool, uds: str):
+    """Start a new streams session."""
     from haupt.cli.runners.streams import start
 
     return start(host=host, port=port, workers=workers, per_core=per_core, uds=uds)
