@@ -1,9 +1,4 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
+from clipped.utils.strings import strip_spaces
 from rest_framework.exceptions import ValidationError
 from rest_framework.filters import BaseFilterBackend
 from rest_framework.filters import OrderingFilter as BaseOrderingFilter
@@ -14,7 +9,6 @@ from django.db.models.fields.json import KeyTransform
 
 from haupt.common import query
 from polyaxon.exceptions import PQLException
-from polyaxon.utils.string_utils import strip_spaces
 
 
 class QueryFilter(BaseFilterBackend):
@@ -53,10 +47,18 @@ class QueryFilter(BaseFilterBackend):
         if check_alive:
             query_spec = self.process_alive(query_spec=query_spec)
 
+        if not query_spec and query_manager and query_manager.DEFAULT_FILTERS:
+            query_spec = ",".join(
+                "{}: {}".format(k, v) for k, v in query_manager.DEFAULT_FILTERS.items()
+            )
+
         if query_spec and query_manager:
             try:
                 queryset = query.filter_queryset(
-                    manager=query_manager, query_spec=query_spec, queryset=queryset
+                    manager=query_manager,
+                    query_spec=query_spec,
+                    queryset=queryset,
+                    request=request,
                 )
             except PQLException as e:
                 if getattr(view, "exception_class", False):
