@@ -1,14 +1,6 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
-
+from clipped.utils.bools import to_bool
 from rest_framework.pagination import LimitOffsetPagination
 
-from polyaxon.utils.bool_utils import to_bool
-
 
 class PolyaxonBasePagination(LimitOffsetPagination):
     no_page_query_param = "no_page"
