@@ -1,10 +1,3 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
-
 from typing import Dict
 
 
@@ -14,7 +7,7 @@ class Result:
     ERROR = "error"
     SEVERITY_VALUES = {INFO, WARNING, ERROR}
 
-    def __init__(self, message="Service is healthy", severity=INFO) -> None:
+    def __init__(self, message="Service is healthy", severity=INFO):
         self.message = message
         if severity not in self.SEVERITY_VALUES:
             raise ValueError("Health check Error not recognized `{}`".format(severity))
