@@ -1,10 +1,5 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
 from rest_framework import status
+from rest_framework.exceptions import ValidationError
 from rest_framework.mixins import CreateModelMixin as DJRCreateModelMixin
 from rest_framework.mixins import DestroyModelMixin as DJRDestroyModelMixin
 from rest_framework.mixins import ListModelMixin as DRFListModelMixin
@@ -65,3 +60,11 @@ class DestroyModelMixin(DJRDestroyModelMixin):
 
     def perform_destroy(self, instance):
         return super().perform_destroy(instance)
+
+
+class StatsMixin:
+    def validate_stats_mode(self):
+        mode = self.request.query_params.get("mode")
+        if mode not in {"stats", "analytics"}:
+            raise ValidationError("Received an unsupported mode: {}".format(mode))
+        return mode
