@@ -1,10 +1,3 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
-
 from haupt.common.events.event import Attribute
 
 OWNER_ATTRIBUTES = (Attribute("id"), Attribute("name"))
@@ -66,6 +59,7 @@ PROJECT_RUN_EXECUTOR_ATTRIBUTES = (
     Attribute("project.owner.name"),
     Attribute("name", is_required=False),
     Attribute("is_managed", attr_type=bool, is_required=False),
+    Attribute("managed_by", attr_type=str, is_required=False),
     Attribute("pipeline_id", attr_type=int, is_required=False),
 )
 
@@ -77,5 +71,6 @@ PROJECT_RUN_EXECUTOR_OWNER_ATTRIBUTES = (
     Attribute("project.owner.name"),
     Attribute("name", is_required=False),
     Attribute("is_managed", attr_type=bool, is_required=False),
+    Attribute("managed_by", attr_type=str, is_required=False),
     Attribute("pipeline_id", attr_type=int, is_required=False),
 )
