@@ -1,16 +1,8 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
-
 from django.db import models
 
 from haupt.db.abstracts.diff import DiffModel
-from haupt.db.abstracts.getter import get_db_model_name
 from haupt.db.abstracts.state import StateModel
-from polyaxon.utils.enums_utils import values_to_choices
+from haupt.db.defs import Models
 from traceml.artifacts import V1ArtifactKind
 
 
@@ -19,23 +11,25 @@ class BaseArtifact(DiffModel, StateModel):
     kind = models.CharField(
         max_length=12,
         db_index=True,
-        choices=values_to_choices(V1ArtifactKind.allowable_values),
+        choices=V1ArtifactKind.to_choices(),
     )
     path = models.CharField(max_length=256, blank=True, null=True)
     summary = models.JSONField()
 
     class Meta:
         abstract = True
+        app_label = "db"
+        db_table = "db_artifact"
 
 
 class BaseArtifactLineage(DiffModel):
     run = models.ForeignKey(
-        get_db_model_name("Run"),
+        Models.get_db_model_name("Run"),
         on_delete=models.CASCADE,
         related_name="artifacts_lineage",
     )
     artifact = models.ForeignKey(
-        get_db_model_name("Artifact"),
+        Models.get_db_model_name("Artifact"),
         on_delete=models.CASCADE,
         related_name="runs_lineage",
     )
@@ -43,3 +37,6 @@ class BaseArtifactLineage(DiffModel):
 
     class Meta:
         abstract = True
+        app_label = "db"
+        db_table = "db_artifactlineage"
+        unique_together = (("run", "artifact", "is_input"),)
