@@ -1,15 +1,9 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
+from typing import Any, Iterable, Optional, Union
 
-from typing import Any, Iterable, Union
+from clipped.utils.bools import to_bool
+from clipped.utils.lists import to_list
 
-from polyaxon import live_state
-from polyaxon.utils.bool_utils import to_bool
-from polyaxon.utils.list_utils import to_list
+from polyaxon.schemas import LiveState, ManagedBy
 from traceml.artifacts import V1ArtifactKind
 
 
@@ -17,8 +11,9 @@ def archived_condition(
     params: Union[str, Iterable],
     negation: bool,
     query_backend: Any,
-    timezone: str = None,
+    timezone: Optional[str] = None,
     queryset: Any = None,
+    request: Optional[Any] = None,
 ) -> Any:
     """
     Example:
@@ -27,24 +22,25 @@ def archived_condition(
     params = to_list(params)
     if len(params) == 1 and to_bool(params[0]) is True:
         return (
-            queryset.filter(live_state=live_state.STATE_ARCHIVED)
+            queryset.filter(live_state=LiveState.ARCHIVED)
             if queryset
-            else query_backend(live_state=live_state.STATE_ARCHIVED)
+            else query_backend(live_state=LiveState.ARCHIVED)
         )
-    return query_backend(live_state=live_state.STATE_LIVE)
+    return query_backend(live_state=LiveState.LIVE)
 
 
 def independent_condition(
     params: Union[str, Iterable],
     negation: bool,
     query_backend: Any,
-    timezone: str = None,
+    timezone: Optional[str] = None,
     queryset: Any = None,
+    request: Optional[Any] = None,
 ) -> Any:
     params = to_list(params)
     if len(params) == 1 and to_bool(params[0]) is True:
-        return queryset.filter(experiment_group__isnull=True)
-    return queryset
+        return query_backend(experiment_group__isnull=True)
+    return None
 
 
 def metric_condition(
@@ -52,12 +48,13 @@ def metric_condition(
     params: Union[str, Iterable],
     negation: bool,
     query_backend: Any,
-    timezone: str = None,
+    timezone: Optional[str] = None,
+    request: Optional[Any] = None,
 ) -> Any:
     params = to_list(params)
     if len(params) == 1 and to_bool(params[0]) is True:
-        return queryset.filter(metric_annotations__name=True)
-    return queryset
+        return query_backend(metric_annotations__name=True)
+    return None
 
 
 def commit_condition(
@@ -65,7 +62,8 @@ def commit_condition(
     params: Union[str, Iterable],
     negation: bool,
     query_backend: Any,
-    timezone: str = None,
+    timezone: Optional[str] = None,
+    request: Optional[Any] = None,
 ) -> Any:
     params = to_list(params)
     if len(params) == 1:
@@ -106,9 +104,10 @@ def in_artifact_kind_condition(
     params: Union[str, Iterable],
     negation: bool,
     query_backend: Any,
-    timezone: str = None,
+    timezone: Optional[str] = None,
+    request: Optional[Any] = None,
 ) -> Any:
-    return _artifact_kind_condition(True, queryset, params, negation)
+    return _artifact_kind_condition(True, query_backend, params, negation)
 
 
 def out_artifact_kind_condition(
@@ -116,6 +115,43 @@ def out_artifact_kind_condition(
     params: Union[str, Iterable],
     negation: bool,
     query_backend: Any,
-    timezone: str = None,
+    timezone: Optional[str] = None,
+    request: Optional[Any] = None,
 ) -> Any:
-    return _artifact_kind_condition(False, queryset, params, negation)
+    return _artifact_kind_condition(False, query_backend, params, negation)
+
+
+def is_managed_condition(
+    queryset: Any,
+    params: Union[str, Iterable],
+    negation: bool,
+    query_backend: Any,
+    timezone: Optional[str] = None,
+    request: Optional[Any] = None,
+) -> Any:
+    params = to_list(params)
+    if len(params) == 1:
+        if (to_bool(params[0]) is True and not negation) or (
+            to_bool(params[0]) is False and negation
+        ):
+            return ~query_backend(managed_by=ManagedBy.USER)
+        else:
+            return query_backend(managed_by=ManagedBy.USER)
+    return None
+
+
+def mine_condition(
+    queryset: Any,
+    params: Union[str, Iterable],
+    negation: bool,
+    query_backend: Any,
+    timezone: Optional[str] = None,
+    request: Optional[Any] = None,
+) -> Any:
+    params = to_list(params)
+    if len(params) == 1:
+        query = query_backend(user=request.user)
+        if negation:
+            return ~query
+        return query
+    return None
