@@ -1,10 +1,4 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
-from typing import List
+from typing import List, Optional
 
 from haupt import settings
 from haupt.proxies.schemas.buffering import get_buffering_config
@@ -19,7 +13,7 @@ from haupt.proxies.schemas.services import (
     get_auth_request_config,
     get_internal_location_config,
     get_k8s_location_config,
-    get_services_location_config,
+    get_services_definitions,
     get_streams_location_config,
 )
 from haupt.proxies.schemas.ssl import get_ssl_config
@@ -32,10 +26,10 @@ def get_scaffold_config(
     use_ssl_config: bool = False,
     use_assets_config: bool = False,
     use_services_configs: bool = False,
-    resolver: str = None,
-    auth: str = None,
-    api_configs: List[str] = None,
-    api_location_configs: List[str] = None,
+    resolver: Optional[str] = None,
+    auth: Optional[str] = None,
+    api_configs: Optional[List[str]] = None,
+    api_location_configs: Optional[List[str]] = None,
     is_local_streams_service: bool = False,
 ) -> List[str]:
     config = [get_listen_config(is_proxy=is_proxy, port=port)]
@@ -71,20 +65,9 @@ def get_scaffold_config(
             get_k8s_location_config(
                 resolver=resolver, auth=auth, is_local_service=is_local_streams_service
             ),
-            get_services_location_config(
-                resolver=resolver, auth=auth, rewrite=False, external=False
-            ),
-            get_services_location_config(
-                resolver=resolver, auth=auth, rewrite=True, external=False
-            ),
-            get_services_location_config(
-                resolver=resolver, auth=auth, rewrite=False, external=True
-            ),
-            get_services_location_config(
-                resolver=resolver, auth=auth, rewrite=True, external=True
-            ),
             # get_plugins_location_config(resolver=resolver, auth=auth)
         ]
+        config += get_services_definitions(resolver=resolver, auth=auth)
     if api_location_configs:
         config += api_location_configs
     return config
