@@ -1,9 +1,3 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
 from haupt import settings
 from haupt.proxies.schemas.base import clean_config, get_config
 from polyaxon.api import (
@@ -36,10 +30,6 @@ def get_api_config(path: str, intercept_errors: str = "on"):
     )
 
 
-def get_streams_config():
-    return get_api_config(path="/", intercept_errors="off")
-
-
 def get_platform_config():
     config = [
         get_api_config(path="= /"),
