@@ -1,10 +1,3 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
-
 from haupt import settings
 from haupt.proxies.schemas.auth import get_auth_config
 from haupt.proxies.schemas.base import clean_config
@@ -12,17 +5,16 @@ from haupt.proxies.schemas.dns import get_resolver
 from haupt.proxies.schemas.gateway.api import get_api_location_config
 from haupt.proxies.schemas.locations import get_streams_locations_config
 from haupt.proxies.schemas.scaffold import get_scaffold_config
-from haupt.proxies.schemas.streams.api import get_streams_config
+from haupt.proxies.schemas.streams.api import get_api_config
 from haupt.proxies.schemas.streams.k8s import get_k8s_root_location_config
+from polyaxon.api import HEALTHZ_LOCATION
 
 
 def get_base_config(is_gateway: bool = True):
     resolver = get_resolver()
     auth = get_auth_config()
-    api_configs = [
-        get_streams_config(),
-    ]
     api_location_configs = [
+        get_api_config(path="= {}".format(HEALTHZ_LOCATION), intercept_errors="off"),
         get_streams_locations_config(),
         get_k8s_root_location_config(),
     ]
@@ -38,7 +30,7 @@ def get_base_config(is_gateway: bool = True):
         use_services_configs=is_gateway,
         resolver=resolver,
         auth=auth,
-        api_configs=api_configs,
+        api_configs=None,
         api_location_configs=api_location_configs,
         is_local_streams_service=True,
     )
