@@ -1,43 +1,41 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
 import logging
 import os
 
 from typing import Dict, List, Optional, Set
 
-import ujson
+from clipped.utils.json import orjson_loads
 
 import aiofiles
 
 from asgiref.sync import sync_to_async
-from polyaxon.fs.async_manager import (
+from polyaxon._fs.async_manager import (
     download_file,
     download_files,
     list_files,
     tar_files,
 )
-from polyaxon.fs.types import FSSystem
+from polyaxon._fs.types import FSSystem
 from traceml.artifacts import V1ArtifactKind
 from traceml.events import V1Events, get_event_path, get_resource_path
 
 logger = logging.getLogger("haupt.streams.events")
 
 
-async def get_events_files(fs: FSSystem, run_uuid: str, event_kind: str) -> List[str]:
+async def get_events_files(
+    fs: FSSystem, store_path: str, run_uuid: str, event_kind: str
+) -> List[str]:
     subpath = get_event_path(run_path=run_uuid, kind=event_kind)
-    files = await list_files(fs=fs, subpath=subpath)
+    files = await list_files(fs=fs, store_path=store_path, subpath=subpath)
     if not files["files"]:
         return []
     return sorted([f for f in files["files"].keys()])
 
 
-async def get_resources_files(fs: FSSystem, run_uuid: str) -> List[str]:
+async def get_resources_files(
+    fs: FSSystem, store_path: str, run_uuid: str
+) -> List[str]:
     subpath = get_resource_path(run_path=run_uuid, kind=V1ArtifactKind.METRIC)
-    files = await list_files(fs=fs, subpath=subpath)
+    files = await list_files(fs=fs, store_path=store_path, subpath=subpath)
     if not files["files"]:
         return []
     return sorted([f for f in files["files"].keys()])
@@ -48,7 +46,7 @@ async def process_operation_event(
     event_kind: str,
     event_name: str,
     orient: str = V1Events.ORIENT_CSV,
-    sample: int = None,
+    sample: Optional[int] = None,
     to_dict: bool = True,
 ) -> Optional[Dict]:
     if not event_path or not os.path.exists(event_path):
@@ -65,6 +63,7 @@ async def process_operation_event(
                     name=event_name,
                     data=contents,
                     parse_dates=False,
+                    engine="pyarrow",
                 )
                 if sample:
                     try:
@@ -89,16 +88,18 @@ async def process_operation_event(
 
 async def get_archived_operation_resource(
     fs: FSSystem,
+    store_path: str,
     run_uuid: str,
     event_kind: str,
     event_name: str,
     orient: str = V1Events.ORIENT_CSV,
     check_cache: bool = True,
-    sample: int = None,
+    sample: Optional[int] = None,
 ) -> Optional[Dict]:
-
     subpath = get_resource_path(run_path=run_uuid, kind=event_kind, name=event_name)
-    event_path = await download_file(fs=fs, subpath=subpath, check_cache=check_cache)
+    event_path = await download_file(
+        fs=fs, store_path=store_path, subpath=subpath, check_cache=check_cache
+    )
 
     return await process_operation_event(
         event_path=event_path,
@@ -111,16 +112,18 @@ async def get_archived_operation_resource(
 
 async def get_archived_operation_event(
     fs: FSSystem,
+    store_path: str,
     run_uuid: str,
     event_kind: str,
     event_name: str,
     orient: str = V1Events.ORIENT_CSV,
     check_cache: bool = True,
-    sample: int = None,
+    sample: Optional[int] = None,
 ) -> Optional[Dict]:
-
     subpath = get_event_path(run_path=run_uuid, kind=event_kind, name=event_name)
-    event_path = await download_file(fs=fs, subpath=subpath, check_cache=check_cache)
+    event_path = await download_file(
+        fs=fs, store_path=store_path, subpath=subpath, check_cache=check_cache
+    )
 
     return await process_operation_event(
         event_path=event_path,
@@ -133,15 +136,17 @@ async def get_archived_operation_event(
 
 async def get_archived_operation_event_and_assets(
     fs: FSSystem,
+    store_path: str,
     run_uuid: str,
     event_kind: str,
     event_name: str,
     check_cache: bool = True,
 ) -> List[str]:
-
     pkg_files = []
     subpath = get_event_path(run_path=run_uuid, kind=event_kind, name=event_name)
-    event_path = await download_file(fs=fs, subpath=subpath, check_cache=check_cache)
+    event_path = await download_file(
+        fs=fs, store_path=store_path, subpath=subpath, check_cache=check_cache
+    )
     pkg_files.append(event_path)
 
     event = await process_operation_event(
@@ -157,7 +162,7 @@ async def get_archived_operation_event_and_assets(
         return []
     df = event["data"].df
     try:
-        files = df[event_kind].map(lambda f: ujson.loads(f).get("path")).tolist()
+        files = df[event_kind].map(lambda f: orjson_loads(f).get("path")).tolist()
     except Exception as e:
         logger.warning(
             "During the packaging of %s, the event format found was not correct. "
@@ -175,16 +180,17 @@ async def get_archived_operation_event_and_assets(
 
 async def get_archived_operation_events_and_assets(
     fs: FSSystem,
+    store_path: str,
     run_uuid: str,
     event_kind: str,
     event_names: Set[str],
     check_cache: bool = True,
 ) -> Optional[str]:
-
     pkg_files = []
     for event_name in event_names:
         event_pkg_files = await get_archived_operation_event_and_assets(
             fs=fs,
+            store_path=store_path,
             run_uuid=run_uuid,
             event_kind=event_kind,
             event_name=event_name,
@@ -200,20 +206,24 @@ async def get_archived_operation_events_and_assets(
 
 async def get_archived_operation_resources(
     fs: FSSystem,
+    store_path: str,
     run_uuid: str,
     event_kind: str,
     event_names: Set[str],
     orient: str = V1Events.ORIENT_CSV,
     check_cache: bool = True,
-    sample: int = None,
+    sample: Optional[int] = None,
 ) -> List[Dict]:
     events = []
     if not event_names:
-        files = await get_resources_files(fs=fs, run_uuid=run_uuid)
+        files = await get_resources_files(
+            fs=fs, store_path=store_path, run_uuid=run_uuid
+        )
         event_names = [f.split(".plx")[0] for f in files]
     for event_name in event_names:
         event = await get_archived_operation_resource(
             fs=fs,
+            store_path=store_path,
             run_uuid=run_uuid,
             event_kind=event_kind,
             event_name=event_name,
@@ -228,17 +238,19 @@ async def get_archived_operation_resources(
 
 async def get_archived_operation_events(
     fs: FSSystem,
+    store_path: str,
     run_uuid: str,
     event_kind: str,
     event_names: Set[str],
     orient: str = V1Events.ORIENT_CSV,
     check_cache: bool = True,
-    sample: int = None,
+    sample: Optional[int] = None,
 ) -> List[Dict]:
     events = []
     for event_name in event_names:
         event = await get_archived_operation_event(
             fs=fs,
+            store_path=store_path,
             run_uuid=run_uuid,
             event_kind=event_kind,
             event_name=event_name,
@@ -253,17 +265,19 @@ async def get_archived_operation_events(
 
 async def get_archived_operations_events(
     fs: FSSystem,
+    store_path: str,
     event_kind: str,
     run_uuids: Set[str],
     event_names: Set[str],
     orient: str = V1Events.ORIENT_CSV,
     check_cache: bool = True,
-    sample: int = None,
+    sample: Optional[int] = None,
 ) -> Dict[str, List]:
     events = {}
     for run_uuid in run_uuids:
         run_events = await get_archived_operation_events(
             fs=fs,
+            store_path=store_path,
             run_uuid=run_uuid,
             event_kind=event_kind,
             event_names=event_names,
