@@ -1,9 +1,3 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
 from typing import List, Tuple
 from urllib.parse import urlparse
 
@@ -12,8 +6,8 @@ from rest_framework import status
 from django.http import HttpResponse
 
 from polyaxon import settings
+from polyaxon._k8s.manager.async_manager import AsyncK8sManager
 from polyaxon.api import K8S_V1_LOCATION
-from polyaxon.k8s.async_manager import AsyncK8SManager
 
 
 def _check_exec(uri_path: List[str], query_params: str):
@@ -50,10 +44,10 @@ async def reverse_k8s(path) -> HttpResponse:
             content="A valid k8s path param is required",
             status=status.HTTP_400_BAD_REQUEST,
         )
-    config = await AsyncK8SManager.load_config(
+    config = await AsyncK8sManager.load_config(
         in_cluster=settings.CLIENT_CONFIG.in_cluster
     )
-    config_auth = AsyncK8SManager.get_config_auth(config)
+    config_auth = AsyncK8sManager.get_config_auth(config)
     return HttpResponse(
         status=status.HTTP_200_OK,
         headers={
