@@ -1,10 +1,4 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
-
+import datetime
 import os
 
 from typing import List, Optional, Tuple
@@ -16,22 +10,25 @@ from haupt.streams.tasks.logs import (
     download_logs_file,
     download_tmp_logs,
 )
-from polyaxon.fs.async_manager import list_files
-from polyaxon.fs.types import FSSystem
-from polyaxon.k8s.async_manager import AsyncK8SManager
-from polyaxon.k8s.logging.async_monitor import query_k8s_operation_logs
-from polyaxon.types import AwareDT
+from polyaxon._fs.async_manager import list_files
+from polyaxon._fs.types import FSSystem
+from polyaxon._k8s.logging.async_monitor import query_k8s_operation_logs
+from polyaxon._k8s.manager.async_manager import AsyncK8sManager
 from traceml.logging import V1Log
 
 
-async def get_logs_files(fs: FSSystem, run_uuid: str) -> List[str]:
-    files = await list_files(fs=fs, subpath="{}/plxlogs".format(run_uuid))
+async def get_logs_files(fs: FSSystem, store_path: str, run_uuid: str) -> List[str]:
+    files = await list_files(
+        fs=fs, store_path=store_path, subpath="{}/plxlogs".format(run_uuid)
+    )
     if not files["files"]:
         return []
     return sorted([f for f in files["files"].keys()])
 
 
-async def get_next_file(files: List[str], last_file: str = None) -> Optional[str]:
+async def get_next_file(
+    files: List[str], last_file: Optional[str] = None
+) -> Optional[str]:
     if not files:
         return None
 
@@ -49,38 +46,45 @@ async def get_next_file(files: List[str], last_file: str = None) -> Optional[str
     return files[i]
 
 
-async def read_logs_file(logs_path) -> List[V1Log]:
+async def read_tmp_logs_file(logs_path) -> List[V1Log]:
     if not logs_path or not os.path.exists(logs_path):
         return []
 
     async with aiofiles.open(logs_path, mode="r") as f:
         content = await f.read()
-        return await content_to_logs(content, logs_path)
+        return await content_to_logs(content, logs_path, to_structured=True)
 
 
 async def get_archived_operation_logs(
-    fs: FSSystem, run_uuid: str, last_file: Optional[str], check_cache: bool = True
+    fs: FSSystem,
+    store_path: str,
+    run_uuid: str,
+    last_file: Optional[str],
+    check_cache: bool = True,
 ) -> Tuple[List[V1Log], Optional[str], List[str]]:
-    files = await get_logs_files(fs=fs, run_uuid=run_uuid)
+    files = await get_logs_files(fs=fs, store_path=store_path, run_uuid=run_uuid)
     logs = []
     last_file = await get_next_file(files=files, last_file=last_file)
     if not last_file:
         return logs, last_file, files
 
     logs = await download_logs_file(
-        fs=fs, run_uuid=run_uuid, last_file=last_file, check_cache=check_cache
+        fs=fs,
+        store_path=store_path,
+        run_uuid=run_uuid,
+        last_file=last_file,
+        check_cache=check_cache,
     )
 
     return logs, last_file, files
 
 
 async def get_tmp_operation_logs(
-    fs: FSSystem, run_uuid: str, last_time: Optional[AwareDT]
-) -> Tuple[List[V1Log], Optional[AwareDT]]:
-
+    fs: FSSystem, store_path: str, run_uuid: str, last_time: Optional[datetime.datetime]
+) -> Tuple[List[V1Log], Optional[datetime.datetime]]:
     logs = []
 
-    tmp_logs = await download_tmp_logs(fs=fs, run_uuid=run_uuid)
+    tmp_logs = await download_tmp_logs(fs=fs, store_path=store_path, run_uuid=run_uuid)
 
     if not tmp_logs or not os.path.exists(tmp_logs):
         return logs, None
@@ -91,7 +95,7 @@ async def get_tmp_operation_logs(
 
     for tmp_file in tmp_log_files:
         logs_path = os.path.join(tmp_logs, tmp_file)
-        logs += await read_logs_file(logs_path)
+        logs += await read_tmp_logs_file(logs_path)
 
     if last_time:
         logs = [l for l in logs if l.timestamp > last_time]
@@ -102,10 +106,10 @@ async def get_tmp_operation_logs(
 
 
 async def get_operation_logs(
-    k8s_manager: AsyncK8SManager,
+    k8s_manager: AsyncK8sManager,
     k8s_operation: any,
     instance: str,
-    last_time: Optional[AwareDT],
+    last_time: Optional[datetime.datetime],
 ):
     previous_last = last_time
     operation_logs, last_time = await query_k8s_operation_logs(
@@ -114,7 +118,7 @@ async def get_operation_logs(
         k8s_manager=k8s_manager,
         stream=True,
     )
-    if k8s_operation["status"].get("completionTime"):
+    if k8s_operation.get("status", {}).get("completionTime"):
         last_time = None
     if previous_last:
         operation_logs = [
