@@ -1,18 +1,16 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
 import logging
 import os
 
-from typing import Dict
-
-import ujson
+from typing import Dict, Optional
 
+from clipped.utils.dates import DateTimeFormatter
+from clipped.utils.hashing import hash_value
+from clipped.utils.json import orjson_dumps, orjson_loads
+from clipped.utils.paths import check_or_create_path
+from clipped.utils.tz import now
 from rest_framework import status
 
+from django.conf import settings as dj_settings
 from django.core.handlers.asgi import ASGIRequest
 from django.db import transaction
 from django.http import HttpResponse
@@ -22,14 +20,15 @@ import aiofiles
 import aiohttp
 
 from haupt.common.endpoints.validation import validate_methods
+from haupt.common.headers import (
+    get_authorization_header,
+    get_original_method_header,
+    get_original_uri_header,
+)
 from haupt.streams.controllers.k8s_check import k8s_check, reverse_k8s
 from polyaxon import settings
+from polyaxon._env_vars.keys import ENV_KEYS_PROXY_LOCAL_PORT
 from polyaxon.api import AUTH_V1_LOCATION
-from polyaxon.env_vars.keys import EV_KEYS_PROXY_LOCAL_PORT
-from polyaxon.utils.date_utils import DateTimeFormatter
-from polyaxon.utils.hashing import hash_value
-from polyaxon.utils.path_utils import check_or_create_path
-from polyaxon.utils.tz_utils import now
 
 logger = logging.getLogger("haupt.streams.auth")
 
@@ -45,20 +44,20 @@ def _get_auth_cache_path(request_cache: str) -> str:
 async def _check_auth_cache(request_cache: str) -> bool:
     cache_path = _get_auth_cache_path(request_cache)
     if os.path.isfile(cache_path):
-        async with aiofiles.open(cache_path, mode="r") as f:
-            last_value = ujson.loads(await f.read())
-            last_time = DateTimeFormatter.extract_timestamp(
-                last_value["time"],
-                dt_format=DateTimeFormatter.DATETIME_FORMAT,
-                timezone=settings.CLIENT_CONFIG.timezone,
-                force_tz=True,
-            )
-            interval = 60 if last_value["response"] else 30
-
-        if (now() - last_time).seconds < interval:
-            return True
-
         try:
+            async with aiofiles.open(cache_path, mode="r") as f:
+                last_value = orjson_loads(await f.read())
+                last_time = DateTimeFormatter.extract_timestamp(
+                    last_value["time"],
+                    dt_format=DateTimeFormatter.DATETIME_FORMAT,
+                    timezone=settings.CLIENT_CONFIG.timezone,
+                    force_tz=True,
+                )
+                interval = 60 if last_value["response"] else 30
+
+            if (now() - last_time).seconds < interval:
+                return True
+
             os.remove(cache_path)
         except Exception as e:
             logger.warning(
@@ -72,14 +71,14 @@ async def _persist_auth_cache(request_cache: str, response: bool):
     cache_path = _get_auth_cache_path(request_cache)
     data = {"time": DateTimeFormatter.format_datetime(now()), "response": response}
     async with aiofiles.open(cache_path, "w") as filepath:
-        await filepath.write(ujson.dumps(data))
+        await filepath.write(orjson_dumps(data))
 
 
 async def _check_auth_service(headers: Dict):
     async with aiohttp.ClientSession(trust_env=True) as session:
         async with session.get(
             "http://localhost:{}{}".format(
-                os.environ[EV_KEYS_PROXY_LOCAL_PORT], AUTH_V1_LOCATION
+                os.environ[ENV_KEYS_PROXY_LOCAL_PORT], AUTH_V1_LOCATION
             ),
             headers=headers,
         ) as resp:
@@ -87,24 +86,26 @@ async def _check_auth_service(headers: Dict):
 
 
 @transaction.non_atomic_requests
-async def auth_request(request: ASGIRequest, methods: Dict = None) -> HttpResponse:
+async def auth_request(
+    request: ASGIRequest, methods: Optional[Dict] = None
+) -> HttpResponse:
     validate_methods(request, methods)
     # Polyaxon checks for origin headers
     try:
-        uri = request.META.get("HTTP_X_ORIGIN_URI")
+        uri = get_original_uri_header(request)
         logger.debug("Authenticating %s" % uri)
         if not uri:
             return HttpResponse(
                 content="Request must comply with an HTTP_X_ORIGIN_URI",
                 status=status.HTTP_403_FORBIDDEN,
             )
-        method = request.META.get("HTTP_X_ORIGIN_METHOD")
+        method = get_original_method_header(request)
         if not method:
             return HttpResponse(
                 content="Request must comply with an HTTP_X_ORIGIN_METHOD",
                 status=status.HTTP_403_FORBIDDEN,
             )
-        auth = request.META.get("HTTP_AUTHORIZATION", "")
+        auth = get_authorization_header(request)
         request_cache = hash_value(
             value={uri.split("?")[0], method, auth}, hash_length=64
         )
@@ -119,14 +120,15 @@ async def auth_request(request: ASGIRequest, methods: Dict = None) -> HttpRespon
     if cached:
         return HttpResponse(status=status.HTTP_200_OK)
 
-    # Contact auth service
-    response = await _check_auth_service(headers=request.headers)
-    if response.status != 200:
-        await _persist_auth_cache(request_cache=request_cache, response=False)
-        return HttpResponse(
-            content="Auth request failed",
-            status=status.HTTP_403_FORBIDDEN,
-        )
+    if dj_settings.POLYAXON_SERVICE == "streams":
+        # Contact auth service
+        response = await _check_auth_service(headers=request.headers)
+        if response.status != 200:
+            await _persist_auth_cache(request_cache=request_cache, response=False)
+            return HttpResponse(
+                content="Auth request failed",
+                status=status.HTTP_403_FORBIDDEN,
+            )
     try:
         path, params = k8s_check(uri)
     except ValueError:
