@@ -1,12 +1,4 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
-
-import ujson
-
+from clipped.utils.json import orjson_dumps
 from rest_framework import status
 
 from django.core.handlers.asgi import ASGIRequest
@@ -34,11 +26,11 @@ class UJSONResponse(HttpResponse):
         if json_dumps_params is None:
             json_dumps_params = {}
         kwargs.setdefault("content_type", "application/json")
-        data = ujson.dumps(data, ensure_ascii=False, **json_dumps_params)
+        data = orjson_dumps(data, **json_dumps_params)
         super().__init__(content=data, **kwargs)
 
 
-class ConfigResponse(UJSONResponse):
+class ConfigResponse(HttpResponse):
     def __init__(
         self,
         data,
