@@ -1,12 +1,7 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
-
-from typing import Dict, Set, Union
+from typing import Dict, Optional, Set, Union
 
+from clipped.utils.bools import to_bool
+from clipped.utils.json import orjson_loads
 from rest_framework import status
 
 from django.core.handlers.asgi import ASGIRequest
@@ -24,7 +19,6 @@ from haupt.streams.controllers.events import (
 )
 from haupt.streams.endpoints.base import UJSONResponse
 from haupt.streams.endpoints.utils import redirect_file
-from polyaxon.utils.bool_utils import to_bool
 from traceml.artifacts import V1ArtifactKind
 from traceml.events import V1Events
 from traceml.processors.importance_processors import calculate_importance_correlation
@@ -37,11 +31,11 @@ async def get_multi_run_events(
     owner: str,
     project: str,
     event_kind: str,
-    methods: Dict = None,
+    methods: Optional[Dict] = None,
 ) -> Union[UJSONResponse, HttpResponse]:
     validate_methods(request, methods)
     force = to_bool(request.GET.get("force"), handle_none=True)
-    if event_kind not in V1ArtifactKind.allowable_values:
+    if event_kind not in V1ArtifactKind.to_set():
         return HttpResponse(
             content="received an unrecognisable event {}.".format(event_kind),
             status=status.HTTP_400_BAD_REQUEST,
@@ -50,11 +44,13 @@ async def get_multi_run_events(
     event_names = request.GET["names"]
     orient = request.GET.get("orient")
     sample = request.GET.get("sample")
+    connection = request.GET.get("connection")
     orient = orient or V1Events.ORIENT_DICT
     event_names = {e for e in event_names.split(",") if e} if event_names else set([])
     run_uuids = {e for e in run_uuids.split(",") if e} if run_uuids else set([])
     events = await get_archived_operations_events(
-        fs=await AppFS.get_fs(),
+        fs=await AppFS.get_fs(connection=connection),
+        store_path=AppFS.get_fs_root_path(connection=connection),
         run_uuids=run_uuids,
         event_kind=event_kind,
         event_names=event_names,
@@ -66,10 +62,11 @@ async def get_multi_run_events(
 
 
 async def get_package_event_assets(
-    run_uuid: str, event_kind: str, event_names: Set[str], force: bool
+    run_uuid: str, event_kind: str, event_names: Set[str], force: bool, connection: str
 ) -> HttpResponse:
     archived_path = await get_archived_operation_events_and_assets(
-        fs=await AppFS.get_fs(),
+        fs=await AppFS.get_fs(connection=connection),
+        store_path=AppFS.get_fs_root_path(connection=connection),
         run_uuid=run_uuid,
         event_kind=event_kind,
         event_names=event_names,
@@ -91,12 +88,12 @@ async def get_run_events(
     project: str,
     run_uuid: str,
     event_kind: str,
-    methods: Dict = None,
+    methods: Optional[Dict] = None,
 ) -> Union[UJSONResponse, HttpResponse]:
     validate_methods(request, methods)
     force = to_bool(request.GET.get("force"), handle_none=True)
     pkg_assets = to_bool(request.GET.get("pkg_assets"), handle_none=True)
-    if event_kind not in V1ArtifactKind.allowable_values:
+    if event_kind not in V1ArtifactKind.to_set():
         return HttpResponse(
             content="received an unrecognisable event {}.".format(event_kind),
             status=status.HTTP_400_BAD_REQUEST,
@@ -104,6 +101,7 @@ async def get_run_events(
     event_names = request.GET["names"]
     orient = request.GET.get("orient")
     sample = request.GET.get("sample")
+    connection = request.GET.get("connection")
     orient = orient or V1Events.ORIENT_DICT
     event_names = {e for e in event_names.split(",") if e} if event_names else set([])
     if pkg_assets:
@@ -112,9 +110,11 @@ async def get_run_events(
             event_kind=event_kind,
             event_names=event_names,
             force=force,
+            connection=connection,
         )
     events = await get_archived_operation_events(
-        fs=await AppFS.get_fs(),
+        fs=await AppFS.get_fs(connection=connection),
+        store_path=AppFS.get_fs_root_path(connection=connection),
         run_uuid=run_uuid,
         event_kind=event_kind,
         event_names=event_names,
@@ -132,17 +132,19 @@ async def get_run_resources(
     owner: str,
     project: str,
     run_uuid: str,
-    methods: Dict = None,
+    methods: Optional[Dict] = None,
 ) -> UJSONResponse:
     validate_methods(request, methods)
     event_names = request.GET.get("names")
     orient = request.GET.get("orient")
     force = to_bool(request.GET.get("force"), handle_none=True)
     sample = request.GET.get("sample")
+    connection = request.GET.get("connection")
     orient = orient or V1Events.ORIENT_DICT
     event_names = {e for e in event_names.split(",") if e} if event_names else set([])
     events = await get_archived_operation_resources(
-        fs=await AppFS.get_fs(),
+        fs=await AppFS.get_fs(connection=connection),
+        store_path=AppFS.get_fs_root_path(connection=connection),
         run_uuid=run_uuid,
         event_kind=V1ArtifactKind.METRIC,
         event_names=event_names,
@@ -159,13 +161,10 @@ async def get_run_importance_correlation(
     namespace: str,
     owner: str,
     project: str,
-    run_uuid: str,
-    methods: Dict = None,
+    methods: Optional[Dict] = None,
 ) -> UJSONResponse:
     validate_methods(request, methods)
-    body = await request.json()
-    data = body.get("data")
-    data = data or {}
+    data = orjson_loads(request.body) if request.body else {}
     params = data.get("params")
     metrics = data.get("metrics")
     return UJSONResponse(
@@ -176,15 +175,12 @@ async def get_run_importance_correlation(
 URLS_RUNS_MULTI_EVENTS = (
     "<str:namespace>/<str:owner>/<str:project>/runs/multi/events/<str:event_kind>"
 )
-URLS_RUNS_EVENTS = (
-    "<str:namespace>/<str:owner>/<str:project>/runs/"
-    "<str:run_uuid>/events/<str:event_kind>"
-)
+URLS_RUNS_EVENTS = "<str:namespace>/<str:owner>/<str:project>/runs/<str:run_uuid>/events/<str:event_kind>"
 URLS_RUNS_RESOURCES = (
-    "<str:namespace>/<str:owner>/<str:project>/runs/" "<str:run_uuid>/resources"
+    "<str:namespace>/<str:owner>/<str:project>/runs/<str:run_uuid>/resources"
 )
 URLS_RUNS_IMPORTANCE_CORRELATION = (
-    "<str:namespace>/<str:owner>/<str:project>/runs/" "<str:run_uuid>/importance"
+    "<str:namespace>/<str:owner>/<str:project>/runs/multi/importance"
 )
 
 # fmt: off
