@@ -1,13 +1,10 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
 import logging
 
-from typing import Dict
+from typing import Dict, Optional
 
+from clipped.utils.bools import to_bool
+from clipped.utils.dates import parse_datetime
+from clipped.utils.serialization import datetime_serialize
 from rest_framework import status
 
 from django.core.handlers.asgi import ASGIRequest
@@ -25,15 +22,13 @@ from haupt.streams.controllers.logs import (
 )
 from haupt.streams.endpoints.base import UJSONResponse
 from haupt.streams.tasks.logs import clean_tmp_logs, upload_logs
+from haupt.streams.tasks.op_spec import upload_op_spec
 from polyaxon import settings
-from polyaxon.k8s.async_manager import AsyncK8SManager
-from polyaxon.k8s.logging.async_monitor import query_k8s_operation_logs
-from polyaxon.utils.bool_utils import to_bool
-from polyaxon.utils.date_utils import parse_datetime
-from polyaxon.utils.fqn_utils import get_resource_name, get_resource_name_for_kind
-from polyaxon.utils.serialization import datetime_serialize
+from polyaxon._k8s.logging.async_monitor import get_op_spec, query_k8s_operation_logs
+from polyaxon._k8s.manager.async_manager import AsyncK8sManager
+from polyaxon._utils.fqn_utils import get_resource_name, get_resource_name_for_kind
 
-logger = logging.getLogger("polyaxon.streams.logs")
+logger = logging.getLogger("haupt.streams.logs")
 
 
 @transaction.non_atomic_requests
@@ -43,10 +38,11 @@ async def get_logs(
     owner: str,
     project: str,
     run_uuid: str,
-    methods: Dict = None,
+    methods: Optional[Dict] = None,
 ) -> UJSONResponse:
     validate_methods(request, methods)
     force = to_bool(request.GET.get("force"), handle_none=True)
+    connection = request.GET.get("connection")
     last_time = request.GET.get("last_time")
     if last_time:
         last_time = parse_datetime(last_time).astimezone()
@@ -56,8 +52,8 @@ async def get_logs(
     if last_time:
         resource_name = get_resource_name(run_uuid=run_uuid)
 
-        k8s_manager = AsyncK8SManager(
-            namespace=settings.CLIENT_CONFIG.namespace,
+        k8s_manager = AsyncK8sManager(
+            namespace=namespace,
             in_cluster=settings.CLIENT_CONFIG.in_cluster,
         )
         await k8s_manager.setup()
@@ -73,20 +69,24 @@ async def get_logs(
             )
         else:
             operation_logs, last_time = await get_tmp_operation_logs(
-                fs=await AppFS.get_fs(), run_uuid=run_uuid, last_time=last_time
+                fs=await AppFS.get_fs(connection=connection),
+                store_path=AppFS.get_fs_root_path(connection=connection),
+                run_uuid=run_uuid,
+                last_time=last_time,
             )
         if k8s_manager:
             await k8s_manager.close()
 
     else:
         operation_logs, last_file, files = await get_archived_operation_logs(
-            fs=await AppFS.get_fs(),
+            fs=await AppFS.get_fs(connection=connection),
+            store_path=AppFS.get_fs_root_path(connection=connection),
             run_uuid=run_uuid,
             last_file=last_file,
             check_cache=not force,
         )
     data = dict(
-        last_time=datetime_serialize("last_time", {"last_time": last_time}),
+        last_time=datetime_serialize(last_time),
         last_file=last_file,
         logs=operation_logs,
         files=files,
@@ -102,21 +102,21 @@ async def collect_logs(
     project: str,
     run_uuid: str,
     run_kind: str,
-    methods: Dict = None,
+    methods: Optional[Dict] = None,
 ) -> HttpResponse:
     validate_methods(request, methods)
     try:
         validate_internal_auth(request)
     except Exception as e:
+        errors = "Request requires an authenticated internal service %s" % e
+        logger.warning(errors)
         return UJSONResponse(
-            data={
-                "errors": "Request requires an authenticated internal service %s" % e
-            },
+            data={"errors": errors},
             status=status.HTTP_400_BAD_REQUEST,
         )
     resource_name = get_resource_name_for_kind(run_uuid=run_uuid, run_kind=run_kind)
-    k8s_manager = AsyncK8SManager(
-        namespace=settings.CLIENT_CONFIG.namespace,
+    k8s_manager = AsyncK8sManager(
+        namespace=namespace,
         in_cluster=settings.CLIENT_CONFIG.in_cluster,
     )
     await k8s_manager.setup()
@@ -124,7 +124,9 @@ async def collect_logs(
         k8s_manager=k8s_manager, resource_name=resource_name
     )
     if not k8s_operation:
-        errors = "Run's logs was not collected, resource was not found."
+        errors = (
+            "Run's logs was not collected, resource was not found for run %s" % run_uuid
+        )
         logger.warning(errors)
         return UJSONResponse(
             data={"errors": errors},
@@ -133,17 +135,25 @@ async def collect_logs(
     operation_logs, _ = await query_k8s_operation_logs(
         instance=run_uuid, k8s_manager=k8s_manager, last_time=None
     )
+    op_spec = await get_op_spec(
+        k8s_manager=k8s_manager, run_uuid=run_uuid, run_kind=run_kind
+    )
     if k8s_manager:
         await k8s_manager.close()
     if not operation_logs:
+        errors = "Operation logs could not be fetched for run %s" % run_uuid
+        logger.warning(errors)
         return HttpResponse(
-            data={"errors": "Operation logs could not be fetched"},
+            content={"errors": errors},
             status=status.HTTP_404_NOT_FOUND,
         )
 
     fs = await AppFS.get_fs()
+    store_path = AppFS.get_fs_root_path()
     try:
-        await upload_logs(fs=fs, run_uuid=run_uuid, logs=operation_logs)
+        await upload_logs(
+            fs=fs, store_path=store_path, run_uuid=run_uuid, logs=operation_logs
+        )
     except Exception as e:
         errors = (
             "Run's logs was not collected, an error was raised while uploading the data. "
@@ -154,15 +164,28 @@ async def collect_logs(
             data={"errors": errors},
             status=status.HTTP_400_BAD_REQUEST,
         )
-    if settings.AGENT_CONFIG.is_replica:
+
+    try:
+        await clean_tmp_logs(fs=fs, store_path=store_path, run_uuid=run_uuid)
+    except Exception as e:
+        errors = "Did not remove temp logs, an error was raised. " "Error %s." % e
+        logger.debug(errors)
+
+    if op_spec:
         try:
-            await clean_tmp_logs(fs=fs, run_uuid=run_uuid)
-        except Exception as e:
-            return HttpResponse(
-                content="Logs collection failed. Error: %s" % e,
-                status=status.HTTP_400_BAD_REQUEST,
+            await upload_op_spec(
+                fs=fs,
+                store_path=store_path,
+                run_uuid=run_uuid,
+                op_spec=op_spec,
             )
-        return HttpResponse(status=status.HTTP_200_OK)
+        except Exception as e:
+            errors = (
+                "Operation spec was not collected, an error was raised while uploading the data. "
+                "Error %s." % e
+            )
+            logger.warning(errors)
+
     return HttpResponse(status=status.HTTP_200_OK)
 
 
