@@ -1,15 +1,8 @@
-#!/usr/bin/python
-#
-# Copyright 2018-2023 Polyaxon, Inc.
-# This file and its contents are licensed under the AGPLv3 License.
-# Please see the included NOTICE for copyright information and
-# LICENSE-AGPL for a copy of the license.
 import logging
 
-from typing import Dict
-
-import ujson
+from typing import Dict, Optional
 
+from clipped.utils.json import orjson_loads
 from rest_framework import status
 
 from django.core.handlers.asgi import ASGIRequest
@@ -21,7 +14,7 @@ from haupt.common.endpoints.validation import validate_methods
 from haupt.streams.endpoints.base import UJSONResponse
 from haupt.streams.tasks.notification import notify_run
 from polyaxon import settings
-from polyaxon.lifecycle import V1StatusCondition
+from polyaxon.schemas import V1StatusCondition
 
 logger = logging.getLogger("haupt.streams.notifications")
 
@@ -33,10 +26,10 @@ async def notify(
     owner: str,
     project: str,
     run_uuid: str,
-    methods: Dict = None,
+    methods: Optional[Dict] = None,
 ) -> HttpResponse:
     validate_methods(request, methods)
-    body = ujson.loads(request.body)
+    body = orjson_loads(request.body)
     run_name = body.get("name")
     condition = body.get("condition")
     if not condition:
